# Infernet ML

### What is Infernet ML?

Ritual provides easy-to-use abstractions for users to create AI/ML workflows that can be
deployed on Infernet nodes.
The [`infernet-ml`](https://github.com/ritual-net/infernet-ml) library is a Python SDK
that provides a set of tools and extendable classes for creating and
deploying machine learning workflows. It is designed to be easy to use, and provides a
consistent interface for data pre-processing, inference, and post-processing of data.

### Batteries Included

We provide a set of pre-built workflows for common use-cases. We have workflows for
running ONNX models, Torch models,
any Huggingface model
via [Huggingface inference client](https://huggingface.co/docs/huggingface_hub/en/package_reference/inference_client)
and even for closed-source models such as OpenAI's GPT-4.

### Getting Started

Head over to the [next section](./quickstart.md) for installation and a quick
walkthrough of
the ML workflows.
